pub enum PathError {
NotAList,
BadSegment,
NotAMap,
NotASequence,
MissingKey,
IndexOutOfBounds,
RemoveIndexUnsupported,
EmptyRemove,
}Expand description
A failure navigating or editing along a path.
Variants
NotAList
The path value was not a list of segments.
BadSegment
A path segment was malformed.
NotAMap
A key segment targeted a non-map value.
NotASequence
An index segment targeted a non-sequence value.
MissingKey
A key segment referenced a missing key (mid-path).
IndexOutOfBounds
An index segment was out of bounds.
RemoveIndexUnsupported
remove_at on a sequence index, which is not supported.
EmptyRemove
remove_at with an empty path.